Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Page
Library
Module
Module type
Parameter
Class
Class type
opam-build and opam-test are two opam plugins:
To install it, simply call:
$ opam install opam-buildThen to use it, in the directory you want to build, simply call:
$ opam buildI hope these plugins help beginners have a more straighforward experience with OCaml.